@@ -54,7 +54,7 @@ bitstream_realloc(bitstream_t *bs) {
     data = (unsigned char *) realloc(bs->data, bs->data_alloc_len);
     if (! data) {
         fprintf(stderr, "bitstream_realloc: Can't realloc memory (%p, %lu)\n",
-                data, bs->data_alloc_len);
+                bs->data, bs->data_alloc_len);
         return 1;
     }
     bs->data = data;
@@ -67,6 +67,12 @@ bitstream_input(bitstream_t *bs, unsigned char *data,
     bitstream_clear(bs);
     bs->data_alloc_len = data_len;
     bs->data = malloc(bs->data_alloc_len);
+    if (bs->data == NULL) {
+        fprintf(stderr, "bitstream_input: malloc failed\n");
+        bs->data_alloc_len = 0;
+        bs->data_len = 0;
+        return 1;
+    }
     memcpy(bs->data, data, data_len);
     bs->data_len = data_len;
     return 0;
@@ -84,11 +90,12 @@ bitstream_steal(bitstream_t *bs, unsigned long *length) {
     *length = bs->data_len;
     if ((tmp = realloc(data, *length)) == NULL) {
         fprintf(stderr, "bitstream_steal: Can't realloc\n");
+        return NULL;
     }
     bs->data = NULL;
     bs->data_len = 0;
     bs->data_alloc_len = 0;
-    return data;
+    return tmp;
 }
 
 unsigned char *
@@ -372,6 +379,11 @@ bitstream_getbytepos(bitstream_t *bs) {
     return bs->byte_offset;
 }
 
+unsigned long
+bitstream_getbitpos(bitstream_t *bs) {
+    return bs->bit_offset;
+}
+
 /*
  * stream info
  */
