@@ -29,6 +29,7 @@
 
 #include "swf_define.h"
 #include "y_keyvalue.h"
+#include "bitmap_util.h"
 
 #include "swf_tag_jpeg.h"
 #include "swf_tag_lossless.h"
@@ -83,6 +84,7 @@ zend_function_entry swfed_functions[] = {
     PHP_ME(swfed,  getPNGData, NULL, 0)
     PHP_ME(swfed,  replacePNGData, NULL, 0)
     PHP_ME(swfed,  replaceGIFData, NULL, 0)
+    PHP_ME(swfed,  replaceBitmapData, NULL, 0)
     PHP_ME(swfed,  applyShapeMatrixFactor, NULL, 0)
     PHP_ME(swfed,  applyShapeRectFactor, NULL, 0)
     PHP_ME(swfed,  getSoundData, NULL, 0)
@@ -105,7 +107,7 @@ zend_function_entry swfed_functions[] = {
 };
 /* }}} */
 
-#define SWFED_VERSION "0.41"
+#define SWFED_VERSION "0.42"
 
 /* {{{ swfed_module_entry
  */
@@ -784,7 +786,7 @@ PHP_METHOD(swfed, getShapeData) {
     swf = get_swf_object(getThis() TSRMLS_CC);
     data = swf_object_get_shapedata(swf, cid, &data_len);
     if (data == NULL) {
-        fprintf(stderr, "getShapeData: Can't swf_object_get_shapedata (cid=%d)\n", cid);
+        fprintf(stderr, "getShapeData: Can't swf_object_get_shapedata (cid=%ld)\n", cid);
         RETURN_FALSE;
     }
     new_buff = emalloc(data_len);
@@ -1061,6 +1063,106 @@ PHP_METHOD(swfed, replaceGIFData) {
 #endif /* HAVE_GIF */
 }
 
+
+#define get_zend_hash_value_long(table, key, value) do { \
+        zval **tmp = NULL; \
+        if (zend_hash_find(table, key, sizeof(key), (void**)&tmp) == SUCCESS) { \
+            convert_to_long_ex(tmp); \
+            value = Z_LVAL_PP(tmp); \
+        } \
+    } while (0);
+
+PHP_METHOD(swfed, replaceBitmapData) {
+    char *data = NULL, *alpha_data = NULL;
+    int data_len = 0 , alpha_data_len = 0;
+    int image_id = 0;
+    zval *image_info = NULL;
+    HashTable *image_info_table = NULL;
+    swf_object_t *swf = NULL;
+    int result = 0;
+    int bitmap_format;
+    int width = -1, height = -1;
+    int red = -1, green = -1, blue = -1;
+    switch (ZEND_NUM_ARGS()) {
+      default:
+        WRONG_PARAM_COUNT;
+        RETURN_FALSE; /* XXX */
+      case 2:
+          if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET,
+                                       ZEND_NUM_ARGS() TSRMLS_CC, "ls", &image_id, &data, &data_len) == SUCCESS) {
+              ; // OK
+          } else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET,
+                                              ZEND_NUM_ARGS() TSRMLS_CC, "as", &image_info, &data, &data_len) == SUCCESS) {
+              ; // OK
+          } else {
+              php_error(E_WARNING, "%s() expects parameter 1 to be long or array given", get_active_function_name(TSRMLS_C));
+              
+              RETURN_FALSE;
+          }
+          break;
+    case 3:
+        if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET,
+                                     ZEND_NUM_ARGS() TSRMLS_CC, "lss", &image_id, &data, &data_len, &alpha_data, &alpha_data_len) == SUCCESS) {
+            ; // OK
+        } else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET,
+                                            ZEND_NUM_ARGS() TSRMLS_CC, "ass", &image_info, &data, &data_len, &alpha_data, &alpha_data_len) == SUCCESS) {
+            ; // OK
+        } else {
+            php_error(E_WARNING, "%s() expects parameter 1 to be long or array given", get_active_function_name(TSRMLS_C));
+            RETURN_FALSE;
+        }
+        break;
+    }
+    swf = get_swf_object(getThis() TSRMLS_CC);
+    
+    if (image_info) {
+        image_info_table = Z_ARRVAL_P(image_info);
+        get_zend_hash_value_long(image_info_table, "width",  width);
+        get_zend_hash_value_long(image_info_table, "height", height);
+        get_zend_hash_value_long(image_info_table, "red",    red);
+        get_zend_hash_value_long(image_info_table, "green",  green);
+        get_zend_hash_value_long(image_info_table, "blue",   blue);
+        image_id = swf_object_search_cid_by_bitmap_condition(swf, width, height,
+                                                             red, green, blue);
+        if (image_id <= 0) {
+            php_error(E_WARNING, "%s() cid not found by bitmap condition(width=%d height=%d red=%d green=%d blue=%d)", get_active_function_name(TSRMLS_C),
+                      width, height, red, green, blue);
+            RETURN_FALSE;
+        }
+    }
+
+    bitmap_format = detect_bitmap_format((unsigned char*) data, data_len);
+    switch (bitmap_format) {
+    case BITMAP_UTIL_FORMAT_JPEG:
+        result = swf_object_replace_jpegdata(swf, image_id,
+                                             (unsigned char *)data,
+                                             (unsigned long) data_len,
+                                             (unsigned char *)alpha_data,
+                                             (unsigned long) alpha_data_len);
+        break;
+    case BITMAP_UTIL_FORMAT_PNG:
+        result = swf_object_replace_pngdata(swf, image_id,
+                                            (unsigned char *)data,
+                                            (unsigned long) data_len);
+        
+        break;
+    case BITMAP_UTIL_FORMAT_GIF:
+        result = swf_object_replace_gifdata(swf, image_id,
+                                            (unsigned char *)data,
+                                            (unsigned long) data_len);
+        
+        break;
+    default:
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "Unknown Bitmap Format");
+        RETURN_FALSE;
+    }
+    
+    if (result) {
+        RETURN_FALSE;
+    }
+    RETURN_TRUE;
+}
+
 PHP_METHOD(swfed, applyShapeMatrixFactor) {
     long shape_id = 0;
     double scale_x = 1, scale_y = 1, rotate_rad = 0;
@@ -1414,7 +1516,6 @@ PHP_METHOD(swfed, setCompressLevel) {
 }
 
 PHP_METHOD(swfed, isShapeTagData) {
-    swf_object_t *swf = get_swf_object(getThis() TSRMLS_CC);
     char *data = NULL;
     int data_len = 0;
     if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC,
@@ -1428,7 +1529,6 @@ PHP_METHOD(swfed, isShapeTagData) {
 }
 
 PHP_METHOD(swfed, isBitmapTagData) {
-    swf_object_t *swf = get_swf_object(getThis() TSRMLS_CC);
     char *data = NULL;
     int data_len = 0;
     if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC,
