@@ -175,9 +175,15 @@ swf_tag_jpeg3_input_detail(swf_tag_t *tag,
     old_buff_ref = bitstream_buffer(bs, offset);
     result = uncompress(new_buff, &origsize, old_buff_ref, alpha_data_len);
     if (result == Z_BUF_ERROR) { // XXX
-      origsize *= 2;
-      new_buff = realloc(new_buff, origsize); // enough size?
-      result = uncompress(new_buff, &origsize, old_buff_ref, alpha_data_len);
+        origsize *= 2;
+        new_buff = realloc(new_buff, origsize); // enough size?
+        if (new_buff == NULL) {
+            free(swf_tag_jpeg);
+            bitstream_close(bs);
+            fprintf(stderr, "swf_tag_jpeg3_create_detail: realloc(%p, %lu) failed\n", new_buff, origsize);
+            return 1;
+        }
+        result = uncompress(new_buff, &origsize, old_buff_ref, alpha_data_len);
     }
     if (result == Z_OK) {
         swf_tag_jpeg->alpha_data = realloc(new_buff, origsize);
@@ -472,7 +478,7 @@ swf_tag_jpeg_replace_jpeg_data(void *detail, int image_id,
         return 1;
     }
     swf_tag_jpeg->image_id = image_id;
-    if (tag->tag == 6) { // DefineBitsJPEG
+    if (tag->code == 6) { // DefineBitsJPEG
         if (jpeg_data && jpeg_data_len) { // fail safe
             free(swf_tag_jpeg->jpeg_data);
             swf_tag_jpeg->jpeg_data = malloc(jpeg_data_len);
