@@ -84,7 +84,7 @@ swf_tag_lossless_input_detail(swf_tag_t *tag,
         int bytes_per_color;
         swf_tag_lossless->colormap_count = bitstream_getbyte(bs) + 1;
         indices_len = ((swf_tag_lossless->width + 3) & -4) * swf_tag_lossless->height;
-        if (tag->tag == 20) { // Lossless => rgb (3 bytes)
+        if (tag->code == 20) { // Lossless => rgb (3 bytes)
             bytes_per_color = 3;
         } else { // Lossless2 => rgba (4 bytes)
             bytes_per_color = 4;
@@ -119,7 +119,7 @@ swf_tag_lossless_input_detail(swf_tag_t *tag,
         }
         bs2 = bitstream_open();
         bitstream_input(bs2, tmp_buff, origsize);
-        if (tag->tag == 20) { // Lossless
+        if (tag->code == 20) { // Lossless
             swf_tag_lossless->colormap = malloc(sizeof(swf_rgb_t) * swf_tag_lossless->colormap_count);
             for (i=0 ; i < swf_tag_lossless->colormap_count ; i++) {
                 swf_rgb_t *rgb = swf_tag_lossless->colormap + i;
@@ -163,7 +163,7 @@ swf_tag_lossless_input_detail(swf_tag_t *tag,
         }
         bs2 = bitstream_open();
         bitstream_input(bs2, tmp_buff, origsize);
-        if (tag->tag == 20) { // Lossless
+        if (tag->code == 20) { // Lossless
             swf_tag_lossless->bitmap = malloc(bitmap_count * sizeof(swf_xrgb_t));
             for (i=0 ; i < bitmap_count ; i++) {
                 swf_xrgb_t *xrgb = swf_tag_lossless->bitmap + i;
@@ -254,7 +254,7 @@ swf_tag_lossless_output_detail(swf_tag_t *tag, unsigned long *length,
         unsigned long indices_len;
         bitstream_putbyte(bs, swf_tag_lossless->colormap_count - 1); /* XXX */
         bs2 = bitstream_open();
-        if (tag->tag == 20) { // Lossless
+        if (tag->code == 20) { // Lossless
             for (i=0 ; i < swf_tag_lossless->colormap_count ; i++) {
                 swf_rgb_t *rgb = swf_tag_lossless->colormap + i;
                 swf_rgb_build(bs2, rgb);
@@ -292,7 +292,7 @@ swf_tag_lossless_output_detail(swf_tag_t *tag, unsigned long *length,
     } else {
         unsigned long bitmap_size;
         bs2 = bitstream_open();
-        if (tag->tag == 20) { // Lossless
+        if (tag->code == 20) { // Lossless
             bitmap_size = swf_tag_lossless->width * swf_tag_lossless->height;
             for (i=0 ; i < bitmap_size ; i++) {
                 swf_xrgb_t *xrgb = swf_tag_lossless->bitmap + i;
@@ -427,7 +427,7 @@ unsigned char *swf_tag_lossless_get_png_data(void *detail,
                 swf_tag_lossless->format);
         return NULL;
     }
-    if (tag->tag == 20) {
+    if (tag->code == 20) {
         if (swf_tag_lossless->format == 3) {
             index_data = (void *) swf_tag_lossless->colormap;
             image_data = (void *) swf_tag_lossless->indices;
@@ -451,7 +451,7 @@ unsigned char *swf_tag_lossless_get_png_data(void *detail,
                                 swf_tag_lossless->height,
                                 index_data,
                                 swf_tag_lossless->colormap_count,
-                                tag->tag, swf_tag_lossless->format,
+                                tag->code, swf_tag_lossless->format,
                                 length);
     return data;
 }
@@ -484,7 +484,7 @@ swf_tag_lossless_replace_png_data(void *detail, int image_id,
         fprintf(stderr, "swf_tag_lossess_replace_png_data: pngconv_png2lossless failed at line(%d)\n", __LINE__);
         return 1;
     }
-    tag->tag = tag_no;
+    tag->code = tag_no;
     swf_tag_lossless->format = format;
     swf_tag_lossless->width  = width;
     swf_tag_lossless->height = height;
@@ -567,7 +567,7 @@ swf_tag_lossless_replace_gif_data(void *detail, int image_id,
         fprintf(stderr, "swf_tag_lossless_replace_gif_data: gifconv_gif2lossless failed at line(%d)\n", __LINE__);
         return 1;
     }
-    tag->tag = tag_no;
+    tag->code = tag_no;
     swf_tag_lossless->format = format;
     swf_tag_lossless->width  = width;
     swf_tag_lossless->height = height;
